@@ -31,7 +31,7 @@
 
 from __future__ import annotations
 
-from typing import Any, Callable, List, Optional, Tuple, Union
+from typing import Any, Callable, Optional
 
 import matplotlib as mlpl  # noqa
 import matplotlib.pyplot as pypl  # noqa
@@ -47,7 +47,11 @@ from matplotlib.pyplot import figure as NewBackendFigure  # noqa
 from mpl_toolkits.mplot3d import Axes3D as backend_frame_3d_t
 
 from babelplot.backend.specification.implemented import backend_e
-from babelplot.backend.specification.plot import UNAVAILABLE_for_this_DIM, plot_e
+from babelplot.backend.specification.plot import (
+    UNAVAILABLE_for_this_DIM,
+    plot_e,
+    plot_type_h,
+)
 from babelplot.brick.log import LOGGER
 from babelplot.type.base import backend_element_h, backend_plot_h
 from babelplot.type.dimension import dim_e
@@ -60,7 +64,7 @@ NAME = backend_e.MATPLOTLIB.value
 
 
 array_t = nmpy.ndarray
-backend_frame_h = Union[backend_frame_2d_t, backend_frame_3d_t]
+backend_frame_h = backend_frame_2d_t | backend_frame_3d_t
 
 
 def _NewFrame(
@@ -88,8 +92,8 @@ def _NewFrame(
 
 
 def _NewPlot(
-    frame: frame_t,
-    type_: Union[str, plot_e, type(backend_plot_h)],
+    frame: backend_frame_h,
+    type_: plot_type_h | type(backend_plot_h),
     plot_function: Optional[Callable],
     *args,
     title: str = None,  # /!\ If _, then it is swallowed by kwargs!
@@ -106,7 +110,7 @@ def _NewPlot(
         else:
             LOGGER.error(f"{type_}: Unknown {NAME} graph object.")
 
-    output = plot_function(frame.backend, *args, **kwargs)
+    output = plot_function(frame, *args, **kwargs)
 
     return output, plot_function
 
@@ -147,11 +151,11 @@ def _Property(element: backend_element_h, name: str, /) -> Any:
     return output
 
 
-def _ShowPreparation(
+def _PrepareForShow(
     figure: backend_figure_t,
-    shape: List[int],
-    frames: List[frame_t],
-    locations: List[Tuple[int, int]],
+    shape: list[int],
+    frames: list[frame_t],
+    locations: list[tuple[int, int]],
     /,
 ) -> None:
     """"""
@@ -172,13 +176,13 @@ def _ShowPreparation(
 
 
 def _Show(
-    figure: backend_figure_t,
+    figure: figure_t,
     /,
 ) -> None:
     """"""
-    figure.show()
+    figure.backend.show()
 
-    event_manager = figure.canvas
+    event_manager = figure.backend.canvas
     event_manager.mpl_connect("close_event", lambda _: event_manager.stop_event_loop())
     event_manager.start_event_loop()
 
@@ -199,7 +203,7 @@ frame_t: base_frame_t = type(
     (base_frame_t,),
     {
         "plot_class": plot_t,
-        "NewBackendPlot": _NewPlot,
+        "NewBackendPlot": staticmethod(_NewPlot),
         "BackendSetProperty": staticmethod(_SetProperty),
         "BackendProperty": staticmethod(_Property),
     },
@@ -212,7 +216,7 @@ figure_t: base_figure_t = type(
         "frame_class": frame_t,
         "NewBackendFigure": staticmethod(NewBackendFigure),
         "NewBackendFrame": staticmethod(_NewFrame),
-        "BackendShowPreparation": staticmethod(_ShowPreparation),
+        "BackendPrepareForShow": staticmethod(_PrepareForShow),
         "BackendShow": staticmethod(_Show),
         "BackendSetProperty": staticmethod(_SetProperty),
         "BackendProperty": staticmethod(_Property),
@@ -376,17 +380,13 @@ def _Bar3(frame: backend_frame_2d_t, *args, **kwargs) -> backend_plot_t:
     if args.__len__() == 1:
         counts = nmpy.asarray(args[0])
         if counts.ndim != 2:
-            LOGGER.error(
-                f"{counts.ndim}: Invalid dimension of counts. Expected=2."
-            )
+            LOGGER.error(f"{counts.ndim}: Invalid dimension of counts. Expected=2.")
         x, y = counts.shape
     else:
         x, y, counts = args
         counts = nmpy.asarray(counts)
         if counts.ndim != 1:
-            LOGGER.error(
-                f"{counts.ndim}: Invalid dimension of counts. Expected=1."
-            )
+            LOGGER.error(f"{counts.ndim}: Invalid dimension of counts. Expected=1.")
     if isinstance(x, int):
         x = range(x)
         y = range(y)
@@ -482,6 +482,8 @@ TRANSLATIONS = {
     "plot_non_finite": "plotnonfinite",
     "size": "s",
     "width_edge": "linewidths",
+    ("AddFrame", "azimuth"): "azim",
+    ("AddFrame", "elevation"): "elev",
     (_Arrows2, "color"): "color",
     (_Arrows3, "color"): "color",
     (_Bar3, "color"): "color",
