@@ -31,7 +31,7 @@
 
 from __future__ import annotations
 
-from typing import Callable, Optional, Union
+from typing import Callable, Optional
 
 import vedo  # noqa
 from numpy import ndarray as array_t
@@ -39,7 +39,7 @@ from vedo import Plotter as backend_figure_t  # noqa
 from vedo import Volume as volume_t  # noqa
 
 from babelplot.backend.specification.implemented import backend_e
-from babelplot.backend.specification.plot import UNAVAILABLE_for_this_DIM, plot_e
+from babelplot.backend.specification.plot import UNAVAILABLE_for_this_DIM, plot_e, plot_type_h
 from babelplot.brick.log import LOGGER
 from babelplot.type.base import backend_plot_h
 from babelplot.type.dimension import dim_e
@@ -68,8 +68,8 @@ def _NewFrame(
 
 
 def _NewPlot(
-    frame: frame_t,
-    type_: Union[str, plot_e, type(backend_plot_h)],
+    frame: backend_frame_t,
+    type_: plot_type_h | type(backend_plot_h),
     plot_function: Optional[Callable],
     *args,
     title: str = None,  # If _, then it is swallowed by kwargs!
@@ -83,7 +83,7 @@ def _NewPlot(
             LOGGER.error(f"{type_}: Unknown {NAME} graph object.")
 
     output = plot_function(*args, **kwargs)
-    frame.backend.__iadd__(output)
+    frame.__iadd__(output)
 
     return output, type(output)
 
@@ -94,18 +94,18 @@ def _IsoSurface(volume: array_t, iso_value: float, *_, **__) -> None:
 
 
 def _Show(
-    figure: backend_figure_t,
+    figure: figure_t,
     /,
 ) -> None:
     """"""
-    figure.show().close()
+    figure.backend.show().close()
 
 
 # noinspection PyTypeChecker
 plot_t: base_plot_t = type("plot_t", (base_plot_t,), {})
 # noinspection PyTypeChecker
 frame_t: base_frame_t = type(
-    "frame_t", (base_frame_t,), {"plot_class": plot_t, "NewBackendPlot": _NewPlot}
+    "frame_t", (base_frame_t,), {"plot_class": plot_t, "NewBackendPlot": staticmethod(_NewPlot)}
 )
 # noinspection PyTypeChecker
 figure_t: base_figure_t = type(
