@@ -32,11 +32,14 @@
 import importlib as mprt
 import sys as sstm
 from pathlib import Path as path_t
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any, Optional
 
 from babelplot.backend.runtime import AddBackendSpecification
 from babelplot.backend.specification.implemented import backend_e
-from babelplot.backend.specification.plot import TranslatedArguments, plot_e
+from babelplot.backend.specification.plot import (
+    TranslatedArguments,
+    plot_type_h,
+)
 from babelplot.brick.log import LOGGER
 from babelplot.type.base import backend_plot_h
 from babelplot.type.dimension import dim_e
@@ -49,9 +52,9 @@ def NewBabelPlotFigure(
     *args,
     title: str = None,
     offline_version: bool = False,
-    pbe: Union[str, path_t, backend_e] = None,
+    pbe: str | path_t | backend_e = None,
     **kwargs,
-) -> figure_t:
+) -> Optional[figure_t]:
     """
     pbe: str=installed module, path_t=path to module, backend_e=implemented backend
     """
@@ -61,60 +64,55 @@ def NewBabelPlotFigure(
         pbe = backend_e.NewFromName(pbe)
 
     if isinstance(pbe, str):
-        backend = mprt.import_module(pbe)
+        module = mprt.import_module(pbe)
     elif isinstance(pbe, path_t):
         module_name = pbe.stem
         spec = mprt.util.spec_from_file_location(module_name, pbe)
-        backend = mprt.util.module_from_spec(spec)
-        sstm.modules[module_name] = backend
-        spec.loader.exec_module(backend)
+        module = mprt.util.module_from_spec(spec)
+        sstm.modules[module_name] = module
+        spec.loader.exec_module(module)
     else:
         try:
-            backend = mprt.import_module(f"babelplot.backend.{pbe.value}_")
+            module = mprt.import_module(f"babelplot.backend.{pbe.value}_")
         except ModuleNotFoundError:
             LOGGER.error(
                 f"{pbe.value}: Unusable backend. "
                 f"Might be due to backend not being installed "
                 f"or implementation error in backend."
             )
+            return None
 
-    if hasattr(backend, "TRANSLATIONS"):
-        translations = backend.TRANSLATIONS
-    else:
-        translations = None
-    AddBackendSpecification(backend.NAME, backend.PLOTS, translations)
+    translations = getattr(module, "TRANSLATIONS", None)
+    AddBackendSpecification(module.NAME, module.PLOTS, translations)
 
-    instance = backend.figure_t(
+    instance = module.figure_t(
         title=title,
         offline_version=offline_version,
-        pbe=backend.NAME,
+        pbe=module.NAME,
     )
-    if hasattr(instance, "NewBackendFigure"):
-        args, kwargs = TranslatedArguments(None, args, kwargs, translations)
-        backend_figure = instance.NewBackendFigure(*args, **kwargs)
-    else:
-        backend_figure = instance
+    args, kwargs = TranslatedArguments("NewBackendFigure", args, kwargs, translations)
+    backend_figure = instance.NewBackendFigure(*args, **kwargs)
     instance.backend = backend_figure
 
     return instance
 
 
 def NewBabelPlot(
-    type_: Union[str, plot_e, type(backend_plot_h)],
+    type_: plot_type_h | type(backend_plot_h),
     *plt_args,
     fig_args=(),
     frm_args=(),
-    fig_kwargs: Dict[str, Any] = None,
-    frm_kwargs: Dict[str, Any] = None,
+    fig_kwargs: dict[str, Any] = None,
+    frm_kwargs: dict[str, Any] = None,
     fig_title: str = None,
     frm_title: str = None,
     plt_title: str = None,
-    dim: Union[str, dim_e] = dim_e.XY,
-    pbe: Union[str, path_t, backend_e] = None,
+    dim: str | dim_e = dim_e.XY,
+    pbe: str | path_t | backend_e = None,
     should_show: bool = True,
     modal: bool = True,
     **plt_kwargs,
-) -> Optional[Tuple[figure_t, frame_t, plot_t]]:
+) -> Optional[tuple[figure_t, frame_t, plot_t]]:
     """"""
     if fig_kwargs is None:
         fig_kwargs = ({},)
