@@ -33,7 +33,7 @@ from __future__ import annotations
 
 import dataclasses as dtcl
 from multiprocessing import Process as process_t
-from typing import List, Optional, Sequence, Tuple, Union
+from typing import Optional, Sequence
 
 from babelplot.backend.runtime import BackendTranslations
 from babelplot.backend.specification.implemented import backend_e
@@ -49,9 +49,9 @@ _unshown_figures = []
 _shown_figures = []
 
 
-def _DefaultShape() -> List[int]:
+def _DefaultShape() -> list[int]:
     """
-    Meant to be a mutable Tuple[int, int]
+    Meant to be a mutable tuple[int, int]
     """
     return [0, 0]
 
@@ -62,9 +62,9 @@ class figure_t(base_figure_t):
     title: str = None
     offline_version: bool = False
     frame_class: type(frame_t) = dtcl.field(init=False, default=None)
-    frames: List[frame_t] = dtcl.field(init=False, default_factory=list)
-    locations: List[Tuple[int, int]] = dtcl.field(init=False, default_factory=list)
-    shape: List[int] = dtcl.field(init=False, default_factory=_DefaultShape)
+    frames: list[frame_t] = dtcl.field(init=False, default_factory=list)
+    locations: list[tuple[int, int]] = dtcl.field(init=False, default_factory=list)
+    shape: list[int] = dtcl.field(init=False, default_factory=_DefaultShape)
 
     def __post_init__(self) -> None:
         """"""
@@ -75,7 +75,7 @@ class figure_t(base_figure_t):
         self,
         *args,
         title: str = None,
-        dim: Union[str, dim_e] = dim_e.XY,
+        dim: str | dim_e = dim_e.XY,
         row: int = 0,
         col: int = 0,
         **kwargs,
@@ -99,7 +99,7 @@ class figure_t(base_figure_t):
             pbe=self.pbe,
         )
         args, kwargs = TranslatedArguments(
-            None, args, kwargs, BackendTranslations(self.pbe)
+            "AddFrame", args, kwargs, BackendTranslations(self.pbe)
         )
         frame.backend = self.NewBackendFrame(
             self.backend, row, col, *args, title=title, dim=dim, **kwargs
@@ -112,7 +112,7 @@ class figure_t(base_figure_t):
 
         return frame
 
-    def LocationOfFrame(self, frame: frame_t, /) -> Tuple[int, int]:
+    def LocationOfFrame(self, frame: frame_t, /) -> tuple[int, int]:
         """"""
         if frame not in self.frames:
             LOGGER.error(f"{frame}: Not a frame of the figure.")
@@ -152,7 +152,7 @@ class figure_t(base_figure_t):
 
         return None
 
-    def RemoveFrame(self, frame: Union[frame_t, Sequence[int]], /) -> None:
+    def RemoveFrame(self, frame: frame_t | Sequence[int], /) -> None:
         """"""
         if isinstance(frame, Sequence):
             location = frame
@@ -195,15 +195,15 @@ class figure_t(base_figure_t):
         # /!\ Must be removed when closed
         _shown_figures.append(self)
 
-        if hasattr(self, "BackendShowPreparation"):
-            self.BackendShowPreparation(
+        if hasattr(self, "BackendPrepareForShow"):
+            self.BackendPrepareForShow(
                 self.backend, self.shape, self.frames, self.locations
             )
 
         if modal:
-            self.BackendShow(self.backend)
+            self.BackendShow(self)
         else:
-            thread = process_t(target=lambda: self.BackendShow(self.backend))
+            thread = process_t(target=lambda: self.BackendShow(self))
             thread.start()
 
     @staticmethod
@@ -246,8 +246,8 @@ def ShowAllFigures(
     """"""
     if all(_fgr.pbe == backend_e.MATPLOTLIB.value for _fgr in _unshown_figures):
         for figure in _unshown_figures:
-            if hasattr(figure, "BackendShowPreparation"):
-                figure.BackendShowPreparation(
+            if hasattr(figure, "BackendPrepareForShow"):
+                figure.BackendPrepareForShow(
                     figure.backend, figure.shape, figure.frames, figure.locations
                 )
 
